@@ -1,9 +1,8 @@
-from diator.events.event import Event, DomainEvent, ECSTEvent, NotificationEvent
+from diator.events.event import DomainEvent, ECSTEvent, Event, NotificationEvent
 from diator.events.event_emitter import EventEmitter
 from diator.events.event_handler import EventHandler
 from diator.events.map import EventMap
 
-
 __all__ = (
     "Event",
     "DomainEvent",
