@@ -9,9 +9,7 @@ E = TypeVar("E", bound=DomainEvent, contravariant=True)
 
 class EventMap:
     def __init__(self) -> None:
-        self._event_map: dict[
-            Type[DomainEvent], list[Type[EventHandler]]
-        ] = defaultdict(lambda: [])
+        self._event_map: dict[Type[DomainEvent], list[Type[EventHandler]]] = defaultdict(lambda: [])
 
     def bind(self, event_type: Type[E], handler_type: Type[EventHandler[E]]) -> None:
         self._event_map[event_type].append(handler_type)
