@@ -1,11 +1,11 @@
 from typing import Type
 
 from diator.container.protocol import Container
+from diator.dispatcher import DefaultDispatcher, Dispatcher
 from diator.events import Event, EventEmitter
 from diator.middlewares import MiddlewareChain
-from diator.requests import RequestMap, Request
+from diator.requests import Request, RequestMap
 from diator.response import Response
-from diator.dispatcher import Dispatcher, DefaultDispatcher
 
 
 class Mediator:
@@ -16,13 +16,17 @@ class Mediator:
 
       redis_client = Redis()  # async redis client
       message_broker = RedisMessageBroker(redis_client)
-      event_map =  EventMap()
+      event_map = EventMap()
       event_map.bind(UserJoinedDomainEvent, UserJoinedDomainEventHandler)
       request_map = RequestMap()
       request_map.bind(JoinUserCommand, JoinUserCommandHandler)
       event_emitter = EventEmitter(message_broker, event_emitter, container)
 
-      mediator = Mediator(request_map, event_emitter, container)
+      mediator = Mediator(
+        event_emitter=event_emitter,
+        request_map=request_map,
+        container=container
+      )
 
       # Handles command and published events by the command handler.
       await mediator.send(join_user_command)
@@ -32,8 +36,8 @@ class Mediator:
     def __init__(
         self,
         request_map: RequestMap,
-        event_emitter: EventEmitter,
         container: Container,
+        event_emitter: EventEmitter,
         middleware_chain: MiddlewareChain | None = None,
         *,
         dispatcher_type: Type[Dispatcher] = DefaultDispatcher,
